@@ -286,6 +286,7 @@ static Rboolean TikZ_Setup(
     tikzInfo->outFileName = calloc_strcpy(fileName);
   }
   tikzInfo->outputFile= NULL;
+  tikzInfo->outColorFileName = NULL;
 
   tikzInfo->originalColorFileName = calloc_strcpy(colorFileName);
   tikzInfo->ncolors = 0;
@@ -1368,14 +1369,22 @@ static void TikZ_Polyline( int n, double *x, double *y,
 
   /* End options, print first set of coordinates. */
   printOutput(tikzInfo, "] (%6.2f,%6.2f) --\n",
-    x[0],y[0]);
+              x[0],y[0]);
+
+  /*Show only for debugging*/
+  if(tikzInfo->debug == TRUE)
+    printOutput(tikzInfo, "%% First point x = %f, y = %f\n", x[0],y[0]);
 
   /* Print coordinates for the middle segments of the line. */
   int i;
   for ( i = 1; i < n-1; i++ ){
 
     printOutput(tikzInfo, "\t(%6.2f,%6.2f) --\n",
-      x[i],y[i]);
+                x[i],y[i]);
+
+    /*Show only for debugging*/
+    if(tikzInfo->debug == TRUE)
+      printOutput(tikzInfo, "%% Next point x = %f, y = %f\n", x[i],y[i]);
 
   }
 
@@ -1383,6 +1392,10 @@ static void TikZ_Polyline( int n, double *x, double *y,
   printOutput(tikzInfo, "\t(%6.2f,%6.2f);\n",
     x[n-1],y[n-1]);
 
+  /*Show only for debugging*/
+  if(tikzInfo->debug == TRUE)
+    printOutput(tikzInfo, "%% Final point x = %f, y = %f\n", x[n-1],y[n-1]);
+
   /*Show only for debugging*/
   if(tikzInfo->debug == TRUE)
     printOutput(tikzInfo,
@@ -1415,6 +1428,10 @@ static void TikZ_Polygon( int n, double *x, double *y,
   printOutput(tikzInfo, "] (%6.2f,%6.2f) --\n",
     x[0],y[0]);
 
+  /*Show only for debugging*/
+  if(tikzInfo->debug == TRUE)
+    printOutput(tikzInfo, "%% First point x = %f, y = %f\n", x[0],y[0]);
+
   /* Print coordinates for the middle segments of the line. */
   int i;
   for ( i = 1; i < n; i++ ){
@@ -1422,6 +1439,10 @@ static void TikZ_Polygon( int n, double *x, double *y,
     printOutput(tikzInfo, "\t(%6.2f,%6.2f) --\n",
       x[i],y[i]);
 
+    /*Show only for debugging*/
+    if(tikzInfo->debug == TRUE)
+      printOutput(tikzInfo, "%% Next point x = %f, y = %f\n", x[i],y[i]);
+
   }
 
   /* End path by cycling to first set of coordinates. */
@@ -1430,7 +1451,7 @@ static void TikZ_Polygon( int n, double *x, double *y,
   /*Show only for debugging*/
   if(tikzInfo->debug == TRUE)
     printOutput(tikzInfo,
-      "%% End Polyline\n");
+      "%% End Polygon\n");
 
 }
 
@@ -1943,7 +1964,9 @@ static void TikZ_WriteLineStyle(pGEcontext plotParams, tikzDevDesc *tikzInfo)
     case GE_MITRE_JOIN:
       /* Default if nothing is specified */
       if(plotParams->lmitre != 10)
-        printOutput(tikzInfo, ",mitre limit=%4.2f",plotParams->lmitre);
+        /* Here it has to be "miter" because pgfkeys wants it to be
+         * written this way. */
+        printOutput(tikzInfo, ",miter limit=%4.2f",plotParams->lmitre);
       break;
     case GE_BEVEL_JOIN:
       printOutput(tikzInfo, ",line join=bevel");
@@ -2133,15 +2156,15 @@ static void Print_TikZ_Header( tikzDevDesc *tikzInfo ){
 
   SEXP currentDate;
   PROTECT(
-    currentDate = eval(lang1( install("getDateStampForTikz") ),
-      namespace )
+    currentDate = lang1( install("getDateStampForTikz") )
   );
+  PROTECT(currentDate = eval(currentDate, namespace));
 
   SEXP currentVersion;
   PROTECT(
-    currentVersion = eval(lang1( install("getTikzDeviceVersion") ),
-      namespace )
+    currentVersion = lang1( install("getTikzDeviceVersion") )
   );
+  PROTECT(currentVersion = eval(currentVersion, namespace));
 
   if( tikzInfo->timestamp )
     printOutput( tikzInfo, "%% Created by tikzDevice version %s on %s\n",
@@ -2153,7 +2176,7 @@ static void Print_TikZ_Header( tikzDevDesc *tikzInfo ){
   if ( tikzInfo->console )
     printOutput(tikzInfo, "\\relax\n");
 
-  UNPROTECT(3);
+  UNPROTECT(5);
 
 }
 
